@@ -57,9 +57,7 @@ except ImportError as error:
 
 
 from numpy import array, array_equal
-from numpy import isnan
 from ._check import InitUnKnowClassError
-from .Normalization import Normalization
 
 
 class Data1D(Data):
